@@ -75,5 +75,5 @@ class ProxyManager:
                 return [] # if there is no proxy left return empty list
             check = self.check_proxy(proxy)
             if check:
-                return [proxy]
+                return proxy
             
\ No newline at end of file
